@@ -728,9 +728,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
         except ValueError:
             self.game_store.add_game_by_id(game.id)
 
-        self.view.set_selected_game(game.id)
-        if game.is_installed:
-            self.game_selection_changed(None, game)
+        self.game_panel.refresh()
         return True
 
     def on_search_games_fire(self, value):
