@@ -129,8 +129,9 @@ class atari800(Runner):
         resolution = self.runner_config.get("resolution")
         if resolution:
             if resolution == "desktop":
-                resolution = display.get_current_resolution()
-            width, height = resolution.split("x")
+                width, height = display.DISPLAY_MANAGER.get_current_resolution()
+            else:
+                width, height = resolution.split("x")
             arguments += ["-fs-width", "%s" % width, "-fs-height", "%s" % height]
 
         if self.runner_config.get("machine"):
