@@ -9,6 +9,7 @@ from lutris.config import LutrisConfig
 from lutris.runners import import_runner
 from lutris.command import MonitoredCommand
 from lutris.util import datapath, system
+from lutris.util.strings import split_arguments
 from lutris.util.log import logger
 from lutris.util.wine.wine import (
     WINE_DIR,
@@ -310,7 +311,7 @@ def wineexec(
     command_parameters = [wine_path]
     if executable:
         command_parameters.append(executable)
-    command_parameters += shlex.split(args)
+    command_parameters += split_arguments(args)
     if blocking:
         return system.execute(command_parameters, env=wineenv, cwd=working_dir)
     wine = import_runner("wine")
