@@ -12,6 +12,7 @@ from lutris import settings
 LIBRETRO_CORES = [
     ("4do (3DO)", "4do", "3DO"),
     ("atari800 (Atari 800/5200)", "atari800", "Atari 800/5200"),
+    ("bsnes (Super Nintendo)", "bsnes", "Nintendo SNES"),
     ("BlastEm (Sega Genesis)", "blastem", "Sega Genesis"),
     ("blueMSX (MSX/MSX2/MSX2+)", "bluemsx", "MSX/MSX2/MSX2+"),
     ("Caprice32 (Amstrad CPC)", "cap32", "Amstrad CPC"),
@@ -32,7 +33,6 @@ LIBRETRO_CORES = [
     ("FBNeo (Arcade)", "fbneo", "Arcade"),
     ("FCEUmm (Nintendo Entertainment System)", "fceumm", "Nintendo NES"),
     ('Flycast (Sega Dreamcast)', 'flycast', 'Sega Dreamcast'),
-    ('Flycast WinCE (Sega Dreamcast)', 'flycast_wince', 'Sega Dreamcast'),
     ("fMSX (MSX/MSX2/MSX2+)", "fmsx", "MSX/MSX2/MSX2+"),
     ("FreeJ2ME (J2ME)", "freej2me", "J2ME"),
     ("Fuse (ZX Spectrum)", "fuse", "Sinclair ZX Spectrum"),
@@ -46,18 +46,21 @@ LIBRETRO_CORES = [
     ("higan balanced(Super Nintendo)", "higan_sfc_balanced", "Nintendo SNES"),
     ("Kronos (Sega Saturn)", "kronos", "Sega Saturn"),
     ("MAME (Arcade)", "mame", "Arcade"),
+    ("MAME 2003-Plus (Arcade)", "mame2003_plus", "Arcade"),
     ("Mednafen GBA (Game Boy Advance)", "mednafen_gba", "Nintendo Game Boy Advance"),
     ("Mednafen NGP (SNK Neo Geo Pocket)", "mednafen_ngp", "SNK Neo Geo Pocket"),
     ("Mednafen PCE (TurboGrafx-16)", "mednafen_pce", "NEC PC Engine (TurboGrafx-16)"),
     ("Mednafen PCE FAST (TurboGrafx-16)", "mednafen_pce_fast", "NEC PC Engine (TurboGrafx-16)"),
     ("Mednafen PCFX (NEC PC-FX)", "mednafen_pcfx", "NEC PC-FX"),
     ("Mednafen Saturn (Sega Saturn)", "mednafen_saturn", "Sega Saturn"),
-    ("Mednafen SGX (NEC PC Engine SuperGrafx)", "mednafen_supergrafx", "NEC PC Engine (SuperGrafx)"),
+    ("Mednafen SGX (NEC PC Engine SuperGrafx)", "mednafen_supergrafx",
+     "NEC PC Engine (SuperGrafx)"),
     ("Mednafen WSWAN (Bandai WonderSwan)", "mednafen_wswan", "Bandai WonderSwan"),
     ("Mednafen PSX (Sony Playstation)", "mednafen_psx", "Sony PlayStation"),
     ("Mednafen PSX OpenGL (Sony Playstation)", "mednafen_psx_hw", "Sony PlayStation"),
     ("Mesen (Nintendo Entertainment System)", "mesen", "Nintendo NES"),
     ("Mesen-S (Super Nintendo)", "mesen-s", "Nintendo SNES"),
+    ("melonDS (Nintendo DS)", "melonds", "Nintendo DS"),
     ("mGBA (Game Boy Advance)", "mgba", "Nintendo Game Boy Advance"),
     ("Mupen64Plus (Nintendo 64)", "mupen64plus", "Nintendo N64"),
     ("Nestopia (Nintendo Entertainment System)", "nestopia", "Nintendo NES"),
@@ -72,9 +75,6 @@ LIBRETRO_CORES = [
     ("PPSSPP (PlayStation Portable)", "ppsspp", "Sony PlayStation Portable"),
     ("ProSystem (Atari 7800)", "prosystem", "Atari 7800"),
     ("QUASI88 (NEC PC-8801)", "quasi88", "NEC PC-8801"),
-    ("Redream (Sega Dreamcast)", "redream", "Sega Dreamcast"),
-    ("Reicast (Sega Dreamcast)", "reicast", "Sega Dreamcast"),
-    ("Reicast WinCE (Sega Dreamcast)", "reicast_wince", "Sega Dreamcast"),
     ("RPG Maker 2000/2003 (EasyRPG)", "easyrpg", "RPG Maker 2000/2003 Game Engine"),
     ("Snes9x (Super Nintendo)", "snes9x", "Nintendo SNES"),
     ("Snes9x2010 (Super Nintendo)", "snes9x2010", "Nintendo SNES"),
