@@ -1,7 +1,6 @@
 """Steam for Linux runner"""
 import os
 import time
-import shlex
 import subprocess
 
 from lutris.runners import NonInstallableRunnerError
@@ -9,6 +8,7 @@ from lutris.runners.runner import Runner
 from lutris.command import MonitoredCommand
 from lutris.util.log import logger
 from lutris.util import system
+from lutris.util.strings import split_arguments
 from lutris.util.steam.config import get_default_acf, read_config
 from lutris.util.steam.vdf import to_vdf
 from lutris.util.steam.appmanifest import get_path_from_appmanifest
@@ -41,7 +41,6 @@ class steam(Runner):
     human_name = "Steam"
     platforms = ["Linux"]
     runner_executable = "steam"
-    runnable_alone = True
     game_options = [
         {
             "option": "appid",
@@ -78,7 +77,7 @@ class steam(Runner):
             "type": "file",
             "label": "Game binary path",
             "advanced": True,
-            "help": "Path to the game executable (Required by DRM free mode)"
+            "help": "Path to the game executable (Required by DRM free mode)",
         },
     ]
     runner_options = [
@@ -143,6 +142,10 @@ class steam(Runner):
         self.no_game_remove_warning = True
         self.original_steampid = None
 
+    @property
+    def runnable_alone(self):
+        return not system.LINUX_SYSTEM.is_flatpak
+
     @property
     def appid(self):
         return self.game_config.get("appid") or ""
@@ -165,12 +168,9 @@ class steam(Runner):
 
     @property
     def game_path(self):
-        if self.appid:
-            for apps_path in self.get_steamapps_dirs():
-                game_path = get_path_from_appmanifest(apps_path, self.appid)
-                if game_path:
-                    return game_path
-            logger.info("Data path for SteamApp %s not found.", self.appid)
+        if not self.appid:
+            return None
+        return self.get_game_path_from_appid(self.appid)
 
     @property
     def steam_data_dir(self):
@@ -189,6 +189,9 @@ class steam(Runner):
                 return path[: -len("SteamApps")]
 
     def get_executable(self):
+        if system.LINUX_SYSTEM.is_flatpak:
+            # Use xdg-open for Steam URIs in Flatpak
+            return system.find_executable("xdg-open")
         if self.runner_config.get("lsi_steam") and system.find_executable("lsi-steam"):
             return system.find_executable("lsi-steam")
         runner_executable = self.runner_config.get("runner_executable")
@@ -209,9 +212,11 @@ class steam(Runner):
     def launch_args(self):
         """Provide launch arguments for Steam"""
         args = [self.get_executable()]
+        if system.LINUX_SYSTEM.is_flatpak:
+            return args
         if self.runner_config.get("start_in_big_picture"):
             args.append("-bigpicture")
-        return args + shlex.split(self.runner_config.get("args") or "")
+        return args + split_arguments(self.runner_config.get("args") or "")
 
     def get_env(self):
         env = super(steam, self).get_env()
@@ -234,17 +239,15 @@ class steam(Runner):
     def get_steamapps_dirs(self):
         """Return a list of the Steam library main + custom folders."""
         dirs = []
-        # Main steamapps dir
+
+        # Main steamapps dir and compatibilitytools.d dir
         if self.steam_data_dir:
-            main_dir = os.path.join(self.steam_data_dir, "SteamApps")
-            main_dir = system.fix_path_case(main_dir)
-            if main_dir and os.path.isdir(main_dir):
-                dirs.append(main_dir)
-        if self.steam_data_dir:
-            ct_dir = os.path.join(self.steam_data_dir, "compatibilitytools.d")
-            ct_dir = system.fix_path_case(ct_dir)
-            if ct_dir and os.path.isdir(ct_dir):
-                dirs.append(ct_dir)
+            for _dir in ["SteamApps", "compatibilitytools.d"]:
+                abs_dir = os.path.join(self.steam_data_dir, _dir)
+                abs_dir = system.fix_path_case(abs_dir)
+                if abs_dir and os.path.isdir(abs_dir):
+                    dirs.append(abs_dir)
+
         # Custom dirs
         steam_config = self.get_steam_config()
         if steam_config:
@@ -318,27 +321,32 @@ class steam(Runner):
                 return {"error": "FILE_NOT_FOUND", "file": binary_path}
             self.original_steampid = None
             command = [binary_path]
-            if game_args:
-                for arg in shlex.split(game_args):
-                    command.append(arg)
         else:
             # Start through steam
 
+            if system.LINUX_SYSTEM.is_flatpak:
+                if game_args:
+                    steam_uri = "steam://run/%s//%s/" % (self.appid, game_args)
+                else:
+                    steam_uri = "steam://rungameid/%s" % self.appid
+                return {
+                    "command": self.launch_args + [steam_uri],
+                    "env": self.get_env(),
+                }
+
             # Get current steam pid to act as the root pid instead of lutris
             self.original_steampid = get_steam_pid()
             command = self.launch_args
-            if game_args:
-                for arg in shlex.split(game_args):
-                    command.append(arg)
 
             if self.runner_config.get("start_in_big_picture") or not game_args:
                 command.append("steam://rungameid/%s" % self.appid)
             else:
                 command.append("-applaunch")
                 command.append(self.appid)
-                if game_args:
-                    for arg in shlex.split(game_args):
-                        command.append(arg)
+
+        if game_args:
+            for arg in split_arguments(game_args):
+                command.append(arg)
 
         return {
             "command": command,
@@ -357,6 +365,6 @@ class steam(Runner):
         command = MonitoredCommand(
             [self.get_executable(), "steam://uninstall/%s" % (appid or self.appid)],
             runner=self,
-            env=self.get_env()
+            env=self.get_env(),
         )
         command.start()
