@@ -2,10 +2,10 @@ import os
 import time
 import requests
 
+from lutris import __version__
 from lutris.util import jobs
 from lutris.util.log import logger
 
-
 # `time.time` can skip ahead or even go backwards if the current
 # system time is changed between invocations. Use `time.monotonic`
 # so we won't have screenshots making fun of us for showing negative
@@ -108,7 +108,8 @@ class Downloader:
             self.callback()
 
     def async_download(self, stop_request=None):
-        headers = {}
+        headers = requests.utils.default_headers()
+        headers["User-Agent"] = "Lutris/%s" % __version__
         if self.referer:
             headers["Referer"] = self.referer
         response = requests.get(self.url, headers=headers, stream=True)
