@@ -2,10 +2,12 @@
 import os
 from lutris.util.wine.registry import WineRegistry
 from lutris.util.log import logger
-from lutris.util import joypad, system
+from lutris.util import joypad, system, xdgshortcuts
 from lutris.util.display import DISPLAY_MANAGER
 
+DESKTOP_KEYS = ["Desktop", "Personal", "My Music", "My Videos", "My Pictures"]
 DESKTOP_FOLDERS = ["Desktop", "My Documents", "My Music", "My Videos", "My Pictures"]
+DESKTOP_XDG = ["DESKTOP", "DOCUMENTS", "MUSIC", "VIDEOS", "PICTURES"]
 
 
 class WinePrefixManager:
@@ -21,11 +23,12 @@ class WinePrefixManager:
     def setup_defaults(self):
         """Sets the defaults for newly created prefixes"""
         self.override_dll("winemenubuilder.exe", "")
-        self.override_dll("steamwebhelper.exe", "")
         try:
             self.desktop_integration()
         except OSError as ex:
-            logger.error("Failed to setup desktop integration, the prefix may not be valid.")
+            logger.error(
+                "Failed to setup desktop integration, the prefix may not be valid."
+            )
             logger.exception(ex)
 
     def get_registry_path(self, key):
@@ -44,6 +47,10 @@ class WinePrefixManager:
             "The key {} is currently not supported by WinePrefixManager".format(key)
         )
 
+    def get_registry_key(self, key, subkey):
+        registry = WineRegistry(self.get_registry_path(key))
+        return registry.query(self.get_key_path(key), subkey)
+
     def set_registry_key(self, key, subkey, value):
         registry = WineRegistry(self.get_registry_path(key))
         registry.set_value(self.get_key_path(key), subkey, value)
@@ -68,11 +75,29 @@ class WinePrefixManager:
             return
         self.set_registry_key(key, dll, mode)
 
-    def desktop_integration(self, desktop_dir=None):
-        """Overwrite desktop integration"""
+    def get_desktop_folders(self):
+        """Return the list of desktop folder names loaded from the Windows registry"""
+        desktop_folders = []
+        for key in DESKTOP_KEYS:
+            folder = self.get_registry_key(
+                self.hkcu_prefix
+                + "/Software/Microsoft/Windows/CurrentVersion/Explorer/Shell Folders",
+                key,
+            )
+            if not folder:
+                logger.warning("Couldn't load shell folder name for %s", key)
+                continue
+            desktop_folders.append(folder[folder.rfind("\\") + 1:])
+        return desktop_folders
 
+
+    def desktop_integration(self, desktop_dir=None, restore=False):
+        """Overwrite desktop integration"""
         user = os.getenv("USER")
         user_dir = os.path.join(self.path, "drive_c/users/", user)
+        _desktop_folders = self.get_desktop_folders()
+        if _desktop_folders:
+            DESKTOP_FOLDERS = _desktop_folders  # pylint: disable=invalid-name
 
         if not desktop_dir:
             desktop_dir = user_dir
@@ -80,13 +105,14 @@ class WinePrefixManager:
             desktop_dir = os.path.expanduser(desktop_dir)
 
         if system.path_exists(user_dir):
-            # Replace desktop integration symlinks
-            for item in DESKTOP_FOLDERS:
+            # Replace or restore desktop integration symlinks
+            for i, item in enumerate(DESKTOP_FOLDERS):
                 path = os.path.join(user_dir, item)
                 old_path = path + ".winecfg"
 
                 if os.path.islink(path):
-                    os.unlink(path)
+                    if not restore:
+                        os.unlink(path)
                 elif os.path.isdir(path):
                     try:
                         os.rmdir(path)
@@ -94,6 +120,11 @@ class WinePrefixManager:
                     except OSError:
                         os.rename(path, old_path)
 
+                if restore and not os.path.isdir(path):
+                    os.symlink(xdgshortcuts.get_xdg_entry(DESKTOP_XDG[i]), path)
+                    # We don't need all the others process of the loop
+                    continue
+
                 if desktop_dir != user_dir:
                     src_path = os.path.join(desktop_dir, item)
                     os.makedirs(src_path, exist_ok=True)
@@ -107,6 +138,7 @@ class WinePrefixManager:
 
             # Security: Remove other symlinks.
             for item in os.listdir(user_dir):
+                path = os.path.join(user_dir, item)
                 if item not in DESKTOP_FOLDERS and os.path.islink(path):
                     os.unlink(path)
                     os.makedirs(path)
@@ -128,12 +160,14 @@ class WinePrefixManager:
         if enabled:
             self.set_registry_key(path, "Desktop", "WineDesktop")
             default_resolution = "x".join(DISPLAY_MANAGER.get_current_resolution())
-            logger.debug("Enabling wine virtual desktop with default resolution of %s",
-                         default_resolution)
+            logger.debug(
+                "Enabling wine virtual desktop with default resolution of %s",
+                default_resolution,
+            )
             self.set_registry_key(
                 self.hkcu_prefix + "/Software/Wine/Explorer/Desktops",
                 "WineDesktop",
-                default_resolution
+                default_resolution,
             )
         else:
             self.clear_registry_key(path)
