@@ -11,15 +11,30 @@ from lutris.util import system
 from lutris.settings import CACHE_DIR
 
 
+def get_xdg_entry(directory):
+    """Return the path for specific user folders"""
+    special_dir = {
+        "DESKTOP": GLib.UserDirectory.DIRECTORY_DESKTOP,
+        "MUSIC": GLib.UserDirectory.DIRECTORY_MUSIC,
+        "PICTURES": GLib.UserDirectory.DIRECTORY_PICTURES,
+        "VIDEOS": GLib.UserDirectory.DIRECTORY_VIDEOS,
+        "DOCUMENTS": GLib.UserDirectory.DIRECTORY_DOCUMENTS,
+    }
+    directory = directory.upper()
+    if directory not in special_dir.keys():
+        raise ValueError("Only those folders are supported " + special_dir.keys())
+    return GLib.get_user_special_dir(special_dir[directory])
+
+
 def get_xdg_basename(game_slug, game_id, base_dir=None):
     """Return the filename for .desktop shortcuts"""
     if base_dir:
         # When base dir is provided, lookup possible combinations
         # and return the first match
         for path in [
-                "{}.desktop".format(game_slug),
-                "{}-{}.desktop".format(game_slug, game_id),
-                "net.lutris.{}-{}.desktop".format(game_slug, game_id),
+            "{}.desktop".format(game_slug),
+            "{}-{}.desktop".format(game_slug, game_id),
+            "net.lutris.{}-{}.desktop".format(game_slug, game_id),
         ]:
             if system.path_exists(os.path.join(base_dir, path)):
                 return path
